# Pysafe maunal
### Description:
Pysafe is a terminal-based password manager with a very easy to use CLI.
### Features:
* Generate a unique encryption key to be used as a master password.
* Generate new passwords for new logins .
* Encrypt all saved password using the generated encryption key.
* Show all your saved login credentials with a click of button.
* Ready to export CSV file for an easy backup experience.
* Master reset to delete all saved login credentials and encryption key.